<div class="container">
    <div class="card border" style="border-color: #E6ECF5;">
        <div class="card-header d-flex justify-content-between align-items-center">
            <h2 class="mb-0">Top-Up Details</h2>
            <div>
                <button wire:click="update" class="btn btn-primary me-2" wire:loading.attr="disabled" wire:target="update">Submit</button>
                <a href="{{ route('top-up') }}" class="btn btn-secondary">Cancel</a>
            </div>
        </div>
        <div class="card-body">
            @if(!$mounted)
                <div class="text-center">
                    <div class="spinner-border text-primary" role="status">
                        <span class="visually-hidden">Loading...</span>
                    </div>
                </div>
            @else
                @if(session('success'))
                    <div class="alert alert-success mb-3" role="alert">
                        {{ session('success') }}
                    </div>
                @endif
                @if(session('error'))
                    <div class="alert alert-danger mb-3" role="alert">
                        {{ session('error') }}
                    </div>
                @endif

                <form wire:submit.prevent="update">
                    <div class="row mb-3">
                        <label for="fee_code" class="col-sm-2 col-form-label">Fee Code</label>
                        <div class="col-sm-6">
                            <input type="text" class="form-control @error('fee_code') is-invalid @enderror" wire:model="fee_code" id="fee_code" placeholder="Fee Code" disabled>
                            @error('fee_code') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>

                    <div class="row mb-3">
                        <label for="name" class="col-sm-2 col-form-label">Name</label>
                        <div class="col-sm-6">
                            <input type="text" class="form-control @error('name') is-invalid @enderror" wire:model="name" id="name" placeholder="Name">
                            @error('name') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>

                    <div class="row mb-3">
                        <label for="amount" class="col-sm-2 col-form-label">Value</label>
                        <div class="col-sm-6">
                            <input type="number" class="form-control @error('amount') is-invalid @enderror" wire:model="amount" id="amount" placeholder="Value" min="0" max="{{ $type == '1' || $type == '' ? '99999.99' : '100' }}" step="{{ $type == '1' || $type == '' ? '0.01' : '1' }}">
                            @error('amount') <div class="invalid-feedback">{{ $message }}</div> @enderror
                        </div>
                    </div>

                    <div class="row mb-3">
                        <label class="col-sm-2 col-form-label">Type</label>
                        <div class="col-sm-6">
                            <div class="form-check form-check-inline">
                                <input class="form-check-input" type="radio" wire:model="type" wire:change="resetAmount" id="type_peso" value="1">
                                <label class="form-check-label" for="type_peso">PH Peso</label>
                            </div>
                            <div class="form-check form-check-inline">
                                <input class="form-check-input" type="radio" wire:model="type" wire:change="resetAmount" id="type_percentage" value="2">
                                <label class="form-check-label" for="type_percentage">Percentage</label>
                            </div>
                            @error('type') <div class="text-danger">{{ $message }}</div> @enderror
                        </div>
                    </div>
                </form>
            @endif
        </div>
    </div>
</div>

@if(session('success'))
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        Swal.fire({
            icon: 'success',
            title: 'Success',
            text: '{{ session('success') }}',
        });
    </script>
@endif

@if(session('error'))
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: '{{ session('error') }}',
        });
    </script>
@endif